<?php
/**
 * @package   FL Business Hours Element for Zoo
 * @author    Дмитрий Васюков http://fictionlabs.ru
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

class ElementFLBusinessHours extends Element implements iSubmittable
{
	// Has Value function

	public function hasValue($params = array())
	{
		$data = $this->data();

		$result = false;

    	if (!empty($data)) {
    		foreach ($data as $key => $value) {
    			$active = (bool) $value['isActive'];
	    		if ($active) {
	    			$result = true;
	    			break;
	    		}
	    	}
    	}
		
		return $result;
	}

	// Get Value For Search Index Function

	public function getSearchData()
	{
		return null;
	}

	// Get Control Name Function

	public function getControlName($name, $array = false)
	{
		return "elements[{$this->identifier}][position][{$name}]" . ($array ? "[]":"");
	}

	// Get Config Form Function

	public function getConfigForm()
	{
        $form = parent::getConfigForm();
        $form->addElementPath($this->app->path->path('elements:flbusinesshours/fields'));
        return $form;
    }

    // Edit Function

	public function edit()
	{
		$template = $this->config->get('timepicker_template', 'classic');

		$this->app->document->addStylesheet('elements:flbusinesshours/assets/css/flbusinesshours_submission.css');
		$this->app->document->addStylesheet('elements:flbusinesshours/assets/css/'.$template.'.picker.css');
		$this->app->document->addStylesheet('elements:flbusinesshours/assets/css/'.$template.'.picker.time.css');

		$this->app->document->addScript('elements:flbusinesshours/assets/js/flbusinesshours.js');
		$this->app->document->addScript('elements:flbusinesshours/assets/js/picker.js');
		$this->app->document->addScript('elements:flbusinesshours/assets/js/picker.time.js');

		if ($layout = $this->getLayout('edit.php')) {
            return $this->renderLayout($layout, array(
            	'operationTime'	=> $this->getOperationTime()
            ));
        }
	}

	// Render Function

	public function render($params = array())
	{
		$this->app->document->addStylesheet('elements:flbusinesshours/assets/css/flbusinesshours.css');

		$params = $this->app->data->create($params);

		if ($layout = $this->getLayout('flbusinesshours.php')) {
            return $this->renderLayout($layout, array(
            	'operationTime'	=> $this->getOperationTime()
            ));
        }
	}

	// Render Submission Function

	public function renderSubmission($params = array())
	{
		return $this->edit();
	}

	// Validate Submission Function

    public function validateSubmission($value, $params)
    {
    	$result = array();

    	foreach ($value as $key => $single_value) {
            try {

                $result[$key]['isActive'] = $this->app->validator->create('string', array('required' => true))->clean($single_value['isActive']);
                $result[$key]['timeFrom']  = $this->app->validator->create('string', array('required' => true))->clean($single_value['timeFrom']);
                $result[$key]['timeTill']  = $this->app->validator->create('string', array('required' => true))->clean($single_value['timeTill']);

            } catch (AppValidatorException $e) {

                if ($e->getCode() != AppValidator::ERROR_CODE_REQUIRED) {
                    throw $e;
                }
            }
        }

        return $result;
    }

    // Get Operation Time Function

    public function getOperationTime()
    {		
    	$operatinTime = array();
    	$data = $this->data();

    	if (!empty($data)) {
    		foreach ($data as $key => $value) {
	    		$operatinTime[] = array(
	    			'isActive' 	=> (bool) $value['isActive'],
	    			'timeFrom'	=> (bool) $value['isActive'] ? $value['timeFrom'] : null,
	    			'timeTill'	=> (bool) $value['isActive'] ? $value['timeTill'] : null,
	    		);
	    	}
    	}

        return $operatinTime;
    }
}